dataName={'amazon','dblp',  'friendster', 'youtube'};
distFilesPath = 'Data/paramDist_gammaH_';
numSamples = 100;

groupAssignment = [];
allCoreSizes = [];
allTailSizes = [];
allLengths = [];

% first assemble all the data to plot
for dataNameIndex=1:length(dataName) 
    d = char(dataName(dataNameIndex));
    disp(['--------' d '-------']);

    disp('read the fitted models');
    f = [distFilesPath d '.csv']; 
    dataArray = textscan(fopen(f,'r'), '%f%f%f%f%f%f%f%[^\n\r]', 'Delimiter', ',',  'ReturnOnError', false);
    coreSize = dataArray{:,2};
    tailSize = dataArray{:,1};
    lengths = dataArray{:,3};

    groupAssignment = [groupAssignment ones(1,length(coreSize))*(dataNameIndex*4-3)];
    allCoreSizes = [allCoreSizes coreSize'];
    allTailSizes = [allTailSizes tailSize'];
    allLengths = [allLengths lengths'];
    
    % add the samples
    for sample = 1:numSamples
        result = load(['Results/' d '_' num2str(sample)], 'comms');
        coreSize = [result.comms(:).p2]';
        tailSize = [result.comms(:).p1]';
        lengths = nan(length(result.comms),1);
        for s = 1:length(result.comms)
            lengths(s) = length(result.comms(s).members);
        end
        
        groupAssignment = [groupAssignment ones(1,length(coreSize))*(dataNameIndex*4-2)];
        allCoreSizes = [allCoreSizes coreSize'];
        allTailSizes = [allTailSizes tailSize'];
        allLengths = [allLengths lengths'];
    end
    
    % add LFR results
    for sample = 1:numSamples
        result = load(['Results/LFRresult_' d '_' num2str(sample)], 'comms');
        coreSize = [result.comms(:).p2]';
        tailSize = [result.comms(:).p1]';
        lengths = nan(length(result.comms),1);
        for s = 1:length(result.comms)
            lengths(s) = length(result.comms(s).members);
        end
    end
    groupAssignment = [groupAssignment ones(1,length(coreSize))*(dataNameIndex*4-1)];
    allCoreSizes = [allCoreSizes coreSize'];
    allTailSizes = [allTailSizes tailSize'];
    allLengths = [allLengths lengths'];
    
    % add DC-SBM results
    if strcmp('friendster', d)
        groupAssignment = [groupAssignment dataNameIndex*4];
        allCoreSizes = [allCoreSizes nan];
        allTailSizes = [allTailSizes nan];
        allLengths = [allLengths nan];        
    else
        result = load(['Results/DCSBMresult_' d], 'comms');
        coreSize = [result.comms(:).p2]';
        tailSize = [result.comms(:).p1]';
        lengths = nan(length(result.comms),1);
        for s = 1:length(result.comms)
            lengths(s) = length(result.comms(s).members);
        end
        groupAssignment = [groupAssignment ones(1,length(coreSize))*(dataNameIndex*4)];
        allCoreSizes = [allCoreSizes coreSize'];
        allTailSizes = [allTailSizes tailSize'];
        allLengths = [allLengths lengths'];
    end    
end

plotData = nan(3,length(allCoreSizes));
plotData(1,:) = allCoreSizes./allLengths;
plotData(2,:) = allTailSizes./allCoreSizes;
plotData(3,:) = allLengths;
%%
boxcolors =[.27 .61 .96; .96 .27 .40; 0.8633    0.7969    0.4648;  .3 .6 .2];
a =1:length(dataName);
positions = reshape([a; a+0.2; a+0.4; a+0.6], [1,4*length(a)]);
xtickpos = mean([a; a+0.6]);
distType = {'relative \gamma','relative H','community size'};
for d = 1:3 
    figure('Name', distType{d});
    bh=boxplot(plotData(d,:),groupAssignment, 'positions', positions, 'Colors', [0 0 0]);
    set(gca,'xtick',xtickpos)
    set(gca,'xticklabel',{'Amazon', 'DBLP', 'Friendster', 'YouTube'});
    h = findobj(gca,'Tag','Box');
    for t=1:length(h)
       patch(get(h(t),'XData'),get(h(t),'YData'),boxcolors(mod(t,4)+1,:),'FaceAlpha',.5,'EdgeColor','none');
    end
    lines = findobj(gcf, 'type', 'line', 'Tag', 'Median');
    set(lines, 'Color', 'r');
    c = get(gca, 'Children');
    if d==3
        ylim([0,1600]);
    end

    set(bh(:), 'LineWidth', 2);
    ylabel(distType{d});
    set(gca,'FontSize',25) 
    set(gca,'FontName','Times New Roman');
    set(gca,'LineWidth',1.5)
    fig=gcf;
    fig.PaperUnits = 'inches';
    fig.PaperPosition = [0 0 7.5 4];
    fig.PaperOrientation = 'landscape';
    path = ['Results/distFitOnReal_', num2str(d), '.pdf'];
    print(path, '-dpdf', '-r0');
    system(strjoin({'pdfcrop' path path}, ' '));
end