function result = createGraphFromObservations(observedGammas, observedHs, ...
    observedSizes, avgDensityInside, avgDensityOutside, targetNumCommunities, ...
    assembleGraph)
%% CREATEGRAPHFROMOBSERVATIONS creates a random graph with hyperbolic community structure
%  Takes the empirical parameter distributions of the core size gamma, the 
%  tail height H, and the community size (all in absolute terms), as well as 
%  the observed densities. Fits the respective distributions and creates a 
%  new graph on their basis. The number of communities in the new graph is 
%  targetNumCommunities. The result is the adjacency matrix of the newly 
%  generated graph if assembleGraph=true. Otherwise, the collection of
%  communities will be returned, each with their hyperbolic model and a 
%  list of global node indices.
%
    relCoreSize = observedGammas./observedSizes;
    relCoreSizeAsInteger = round(relCoreSize * 1000);
    relTailSize = observedHs./observedSizes;
    relTailSizeAsInteger = round(relTailSize * 1000) + 1; %let's move this to strictly positive as the dist doesn't like 0s
     
    gammaDist = fitdist(relCoreSizeAsInteger(relCoreSizeAsInteger>0),'Normal');
    HDist = fitdist(relTailSizeAsInteger(relTailSizeAsInteger>0),'Exponential');
    sizeDist = fitdist(observedSizes,'GeneralizedExtremeValue');
    sizeRange = [min(observedSizes),max(observedSizes)];

    result = createGraph('H,gamma', HDist, gammaDist, sizeDist, sizeRange, ...
                         avgDensityInside, avgDensityOutside, ...
                         targetNumCommunities, assembleGraph);
end

