% computes the relative conditional entropy
dataName={'youtube', 'amazon','dblp',  'friendster'};
genGraphsPath = 'Results/'; % Note that we need the results of 
                            % generateFromFit in this folder with
                            % sizeVariation = 0
origGraphPath = 'Data/';
numSamples = 100;
computeConditionalEntropy = true;

for dataNameIndex=1:length(dataName) 
    d = char(dataName(dataNameIndex));
    disp(['--------' d '-------']);

    disp('read the fitted models');
    
    % generate a graph as it was observed from the original data - i.e.
    % just the communities we sampled for the model generation
    % without any overlaps
    load([origGraphPath 'result_individualComm_'  d '_100_1000_sample500_v2.mat']);
    numCommunities = length(res);
    commSizes = nan(numCommunities,1);
    for s = 1:numCommunities
        commSizes(s) = length(res(s).members);
    end
    maxNodeIndex = sum(commSizes);
    [~,commOrder] = sort(commSizes, 'ascend');
    originalGraph = sparse(maxNodeIndex, maxNodeIndex);
    originalCommunities = cell(numCommunities,1);
    lengthSoFar = 0;
    for t = 1:numCommunities
        c = commOrder(t);
        block = (lengthSoFar + 1) : (lengthSoFar + commSizes(c));
        originalCommunities{t} = degree_ord(res(c).comm);
        originalGraph(block,block) = originalCommunities{t};
        lengthSoFar = lengthSoFar + commSizes(c);
    end

    relativeCondEntropy = nan(numCommunities,numSamples);
    for sample = 1:numSamples
        fprintf('.');
        if sample == 1
            otherSample = 'original';
        else
            otherSample = sprintf('sample %d', sample-1);
        end
        toPlot = {sprintf('sample %d', sample),otherSample};
        result = load([genGraphsPath d '_' num2str(sample)], 'comms');%, 'gammaDist', 'sizeDist');
        commSizes = nan(length(result.comms),1);
        for s = 1:length(result.comms)
            commSizes(s) = length(result.comms(s).members);
        end
        maxNodeIndex = sum(commSizes);
        generatedGraph = sparse(maxNodeIndex, maxNodeIndex);
        generatedCommunities = cell(length(result.comms),1);
        [~,commOrder] = sort(commSizes, 'ascend');% so we compare equal sized communities in the conditional entropy computation
        for t = 1:length(result.comms)
            s = commOrder(t);
            generatedCommunities{t} = degree_ord(result.comms(s).comm);
            generatedGraph(result.comms(s).members,result.comms(s).members) = generatedCommunities{t}; % there is no overlap!
        end
        
        % the conditional entropy can only be evaluated if the sizes of the
        % generated graphs are fixed to the observed community sizes.
        if length(generatedGraph) ~= size(originalGraph)
            error('Conditional entropy can only be computed of graphs of the same size.');
        end
        for s = 1:numCommunities
            H_generatedGivenOriginal = conditionalEntropy(generatedCommunities{s}, originalCommunities{s});
            H_generated = entropy(generatedCommunities{s});
            % relative H is within (0,1) as H(Y|X) = H(Y) if X and Y are independent
            relativeCondEntropy(s,sample) = H_generatedGivenOriginal/H_generated;
        end
    end
    save(['Results/relativeConditionalEntropy_' d],'relativeCondEntropy');
    fprintf('\n');
end
%% output relative conditional entropy
fprintf('relative conditional entropy per dataset:\n');
for dataNameIndex=1:length(dataName) 
    d = char(dataName(dataNameIndex));
    load(['Results/relativeConditionalEntropy_' d '.mat'])
    fprintf('%s\t%f(%f)\n', d, mean(relativeCondEntropy(:)), var(relativeCondEntropy(:)));
end